import csv
from math import prod
from itertools import product

class UnitFrame:
    """
    UnitFrame is the core datastrucutre of this package. It is a vertaline n-dimensonal class for numerical operations.
    It provides a minimal, python-native alternative to libraries like numpy.
    """
    def __init__(self, data=None, shape=None, fill_value=0.0):
        pass

    