"""
PyLearn-AI: A pure-Python machine learning and deep learning framework.

Version: 0.1.0b3
"""

__version__ = "0.1.0b3"

__all__ = [
    "core",
    "neural",
    "reinforcement",
    "supervised",
    "unsupervised",
    "utils",
]
